@@ -6,10 +6,6 @@ import (
 	"device/nrf"
 )
 
-var (
-	UART0 = NRF_UART0
-)
-
 func CPUFrequency() uint32 {
 	return 16000000
 }
@@ -19,7 +15,7 @@ func (p Pin) getPortPin() (*nrf.GPIO_Type, uint32) {
 	return nrf.GPIO, uint32(p)
 }
 
-func (uart UART) setPins(tx, rx Pin) {
+func (uart *UART) setPins(tx, rx Pin) {
 	nrf.UART0.PSELTXD.Set(uint32(tx))
 	nrf.UART0.PSELRXD.Set(uint32(rx))
 }
