@@ -228,6 +228,14 @@ func setHeapEnd(newHeapEnd uintptr) {
 // This function can be called again when the heap size increases. The caller is
 // responsible for copying the metadata to the new location.
 func calculateHeapAddresses() {
+	if GOARCH == "wasm" {
+		// This is a workaround for a bug in wasm-ld: wasm-ld doesn't always
+		// align __heap_base and when this memory is shared through an API, it
+		// might result in unaligned memory. For details, see:
+		// https://reviews.llvm.org/D106499
+		// It should be removed once we switch to LLVM 13, where this is fixed.
+		heapStart = align(heapStart)
+	}
 	totalSize := heapEnd - heapStart
 
 	// Allocate some memory to keep 2 bits of information about every block.
